
# q-expansion of newform 1600.2.s.d, downloaded from the LMFDB on 10 February 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1600
weight = 2
poly_data = [512, 0, 256, -256, -160, -224, -80, 24, 74, 70, 37, 6, -10, -14, -5, -4, 2, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-28416, -21696, -31296, -9920, 848, 13500, 15406, 10894, 4379, -583, -2676, -2550, -1487, -375, 6, 248, 89, 75], 640], [[38912, 4736, 8896, -36256, -40656, -42352, -24152, -3462, 10426, 14845, 11894, 6294, 1614, -997, -1252, -1110, -380, -191], 1280], [[-90496, -75776, -103296, -35040, 4368, 45600, 51206, 35784, 13989, -2433, -9096, -8400, -4757, -1145, 106, 798, 299, 225], 640], [[196480, 115392, 165632, -1648, -64880, -126996, -108530, -56742, -5453, 24377, 29756, 20942, 9185, 249, -1810, -2732, -951, -613], 640], [[267008, 210048, 295808, 95120, -12944, -130120, -145098, -101032, -39447, 6959, 25688, 23760, 13511, 3215, -198, -2314, -817, -655], 640], [[46208, 32320, 45504, 8592, -8624, -26316, -25600, -15672, -4196, 3435, 5762, 4568, 2280, 321, -232, -524, -186, -129], 128], [[513280, 383744, 537024, 137024, -63920, -275192, -284460, -185094, -60796, 26869, 57922, 48934, 25980, 4903, -1600, -5234, -1882, -1371], 1280], [[-528640, -381952, -540992, -125312, 77840, 288616, 291940, 185642, 56748, -32027, -61646, -50762, -26220, -4409, 2000, 5582, 1966, 1413], 1280], [[-277120, -183872, -260352, -32912, 66320, 166636, 154530, 89642, 19033, -25777, -37596, -28402, -13525, -1369, 1850, 3432, 1211, 813], 640], [[-303232, -220288, -313728, -75136, 40416, 164208, 167822, 108104, 34317, -17157, -34920, -29216, -15309, -2757, 1042, 3182, 1131, 829], 640], [[-588032, -405376, -575296, -103264, 113296, 337152, 326212, 198282, 51964, -45185, -74354, -58634, -29124, -3963, 3072, 6790, 2410, 1671], 1280], [[-306816, -209920, -299520, -54624, 56368, 172232, 167186, 102398, 27445, -22322, -37538, -29814, -14917, -2108, 1466, 3432, 1201, 856], 640], [[-670720, -466944, -661184, -127424, 119760, 376472, 368520, 226774, 62446, -47679, -81842, -65414, -32910, -4833, 3140, 7454, 2632, 1861], 1280], [[-372864, -258560, -364800, -67376, 69792, 211368, 205144, 125222, 33350, -27653, -46182, -36566, -18238, -2547, 1844, 4198, 1484, 1039], 640], [[-807680, -542976, -767296, -110976, 179280, 476008, 448020, 264246, 61024, -70181, -106298, -81686, -39440, -4527, 4920, 9706, 3438, 2339], 1280], [[-496256, -355008, -505408, -112112, 74528, 272636, 274106, 173656, 52407, -30930, -58602, -48112, -24827, -4144, 1966, 5350, 1895, 1368], 640], [[1253888, 893824, 1258944, 268896, -203344, -692848, -689368, -431518, -125726, 82065, 149166, 121006, 61766, 9767, -5268, -13550, -4780, -3419], 1280]]

hecke_ring_character_values = [[1151, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [901, [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [577, [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0], [-1, 0, 0, 0, -1, 0, 1, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1, -1], [1, 1, 0, 1, 0, 0, -1, 1, -1, 1, 0, 0, -1, 0, 1, 0, 0, 0], [-1, 0, 0, 0, 0, -1, 1, -1, 1, 1, 1, 0, 0, 0, -1, 1, -1, 0], [1, 0, 0, 0, -1, 0, 1, 0, 0, 0, 0, -1, -1, 0, 0, 0, 1, -1], [1, 0, -1, 0, 1, 0, 1, 0, -1, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, -1, 0, 0, 1, 1, 0, 1, 0, 0, -1, 0], [0, 0, -1, 0, 0, 0, 0, -1, 0, -1, 0, 1, 1, 1, 0, 0, -1, 0], [0, 0, 1, 0, 0, 0, 2, 1, 0, 0, -2, 0, 0, 0, 1, 0, 2, 0], [3, 0, 0, 1, 0, 0, -3, 1, -1, 1, 0, 0, -1, 0, 0, 1, 0, 0], [-2, 0, 1, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1], [-2, 1, 2, -1, -1, -2, -2, 0, 0, 0, -2, 0, -2, 0, 1, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, -2, 0, -1, 0, 0, 0, -2, 0, 0, 0, 0], [-1, 0, -1, 0, -1, 0, 3, -2, 1, 1, 0, -1, -1, -1, 1, 1, 1, -1], [-2, 0, 1, -2, 0, -2, 0, -1, 0, -1, 0, 0, 0, 0, 0, 0, 1, 0], [0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, -1, 1], [2, -4, -1, 0, 0, 2, 0, 1, 0, -1, 0, 0, 0, 0, 0, 1, 1, 1], [3, -1, 1, 2, -1, 2, -1, 0, -1, -1, 0, 0, -1, 0, 0, 0, 1, 0], [-1, 2, 0, 0, 1, 2, 1, -1, 1, 0, 0, 3, 1, -3, 0, 1, 0, 1], [-2, 3, 1, 0, -1, -1, -2, 0, 0, 0, -1, 2, -1, 0, -2, 0, 0, 1], [-1, 1, 2, -2, 1, -1, -1, 0, 0, 0, -1, 3, -1, 0, 0, 0, 2, 1], [-1, -2, 0, -2, 0, 1, 1, -1, 1, -1, -1, 0, 2, 2, -1, -1, 1, 0], [-1, 1, 2, -4, 1, -2, 1, -3, 1, 1, 0, 1, 1, -1, 0, 1, -1, 1], [0, -3, 0, -1, 0, -1, 0, 0, 0, 0, -1, -2, -1, 0, 4, 0, 0, 2], [-1, 0, 0, -1, 0, 0, 1, -2, 2, 0, 0, 0, 1, -2, 0, 2, 0, 0], [-2, -2, 0, -1, 0, 1, 2, 0, 0, -4, -1, 0, 1, 1, -1, 0, 1, 0], [0, 0, 0, -1, 1, 2, 0, 0, 0, 0, 2, 2, 0, 0, -2, 0, -3, 0], [-1, -2, 0, 1, 0, 2, 1, 0, 0, 0, -2, 0, -1, 0, 0, 0, 2, 0], [0, -1, 4, -2, 2, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1, 0, 4, 1], [0, -2, 0, -1, 0, -2, 0, -2, -2, -1, 2, 0, 1, 0, -4, 0, -2, 0], [5, -4, 0, 0, -1, 0, -1, 1, -1, 1, 0, -1, -1, 1, 0, 0, -1, 0], [-1, 1, 0, -2, -1, -1, -1, 1, -1, 0, 0, -1, -1, 1, 0, -1, 0, -1], [-9, 3, 0, -2, 1, -4, 1, -1, 1, 3, 0, 1, 1, -1, 0, 1, -3, 1], [-4, 2, 0, 2, -3, 1, -4, 0, 0, 0, 1, 0, -1, 0, -3, 0, -4, -1], [2, 0, -1, 0, 2, 0, 2, 1, -2, 0, -1, 1, 0, 1, 4, 0, 1, 0], [0, 3, 0, 0, 0, -2, 0, -4, 2, 2, 2, 0, 0, -5, 1, 1, -2, 0], [1, -2, 0, -1, 3, -2, 1, 0, 0, 0, -2, -3, 2, 0, 4, 0, 1, 1], [-2, 0, 0, 0, -2, 0, 6, -2, 2, 0, -2, -1, 0, -1, 2, 0, 2, 0], [-3, -3, 0, -1, 0, 1, 3, -2, 3, -3, -1, 0, 1, 0, -2, 1, 1, 0], [0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 1, 3, 1, 4, -1, 0, 1], [1, 0, -1, 0, 1, 0, 1, 0, -1, 2, 4, 0, 3, 0, 0, 1, -2, -1], [-6, 2, 2, -1, 1, -2, -6, 0, 0, 0, -2, 0, 0, 0, 0, 0, 1, 2], [0, 0, -2, 3, -2, 3, 0, 0, 0, 0, 3, -1, 1, 0, -3, 0, -3, -2], [2, 0, 2, 0, 2, 0, 2, 4, -2, 2, 0, 1, -2, 1, 3, -3, 2, 3], [4, 5, 0, 1, 0, -1, -4, 1, -1, 1, 1, 0, -1, 3, 4, -3, -1, 0], [0, -2, -1, 1, -3, 2, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 3, -3], [8, 0, -1, 2, -2, 4, -2, 3, -2, -3, 0, -2, -2, 2, 0, -3, 3, -3], [-1, 2, -1, -1, 3, 2, 3, -2, 3, 0, 0, 2, 3, -2, 0, 1, 0, 1], [-6, -2, 0, 0, 0, 0, 6, -2, 4, 4, 0, 0, 0, 1, -2, 3, 0, 0], [-1, -1, 2, -2, 2, 3, -1, 0, 0, 0, 3, -2, 0, 0, -2, 0, 1, 0], [4, -2, 0, 0, 0, 2, -4, 0, -2, -2, -2, 0, 0, -3, 0, 4, 2, 0], [0, -5, -2, 0, 0, 1, 0, 0, 0, 0, 1, -2, 0, 0, 4, 0, 2, -4], [1, 0, -1, 0, 1, 0, -3, 0, -1, -2, 2, 2, 3, 2, -6, -2, -4, 2], [3, 0, -1, 0, 3, 0, -5, 2, -3, -2, -1, 0, -1, 0, 0, -3, -1, 3], [-3, 0, -1, 0, -3, 0, 5, -4, 3, -3, -2, 0, 2, 0, -4, -1, -1, 1], [2, 0, 0, 0, 2, 0, -6, 2, -2, 2, 2, -1, 0, -1, 3, -1, 0, 1], [7, 5, 2, 2, -1, -1, -1, -1, -1, 0, 0, 3, -1, -3, 0, 1, 0, 1], [2, 0, 1, 0, 2, 0, -12, 3, -2, -2, 0, -2, 0, -2, 1, -2, -2, 2], [3, 4, 2, -2, 1, 2, 1, -3, 1, -1, 0, -1, 1, 1, 0, 0, 1, 0], [-3, 4, 0, -2, 2, 0, -3, 0, 0, 0, 0, -2, 0, 0, -4, 0, -4, -2], [8, 4, -2, 5, 2, 0, 2, 0, 2, 1, 0, -1, 2, 1, 0, 1, -1, 1], [-5, 2, 0, -3, 0, -2, 5, -5, 5, 3, 2, 0, 3, -6, 0, 2, -2, 0], [-3, -3, -2, 1, -2, 1, -3, 0, 0, 0, 1, -2, -1, 0, 2, 0, -3, 0], [-13, -1, -1, -2, 3, 2, 3, -2, 3, -1, 0, -2, 3, 2, 0, 0, 1, 0], [-1, 5, 2, -3, 1, -1, -1, 0, 0, 0, -1, 1, -2, 0, -4, 0, 0, -1], [-1, -2, 0, -2, 0, -2, 1, -2, -2, 4, 2, 0, 2, -2, -4, 2, -2, 0], [2, 0, 0, 0, 2, 0, -10, 2, -2, 0, 0, 1, 0, 1, 0, -3, 0, 3], [4, 4, 0, -1, 0, -1, -4, 2, 0, 4, 1, 0, 1, -1, 3, 0, -1, 0], [3, -3, -3, 0, -1, -1, -1, 4, -1, 1, 0, -2, -1, 2, 0, -1, -1, -1], [-2, 1, -2, 0, 6, 0, -2, 0, 0, 0, 0, 5, 6, 0, -1, 0, -4, 3], [-6, -4, 0, -1, -2, 1, -6, 0, 0, 0, 1, 1, -3, 0, 3, 0, 3, -2], [2, 3, 0, 2, 0, 1, -2, 6, -4, -1, -1, 0, -2, -2, 4, 0, 1, 0], [-1, -2, 0, -1, 1, -2, 1, -1, 1, 3, 0, -2, 1, 2, 0, -2, -3, -2], [0, 6, 3, 0, -2, -2, -2, -1, -2, 1, 0, -1, -2, 1, 0, 2, -1, 2], [4, 0, -1, -1, 2, 0, 2, -1, 2, 1, 0, -5, 2, 5, 0, -2, -1, -2], [4, -3, 0, 0, 0, 0, -4, 0, -4, -4, 0, 0, 0, -1, -3, 1, 0, 0], [2, -1, -4, -1, 0, 1, 2, 0, 0, 0, 1, -6, -1, 0, 0, 0, -4, -2], [4, 0, 3, 0, 4, 0, -10, 7, -4, 1, -2, -1, 0, -1, 10, -1, 3, 1], [5, 4, 0, 3, 0, 0, -5, 2, -1, 1, 0, 0, -3, 2, 4, -5, 0, 0], [-2, 0, 0, 0, -2, 0, 10, -2, 2, 0, -4, -3, 0, -3, 0, -1, 4, 1], [1, 0, -2, 0, 1, 0, -1, -1, -1, -1, 2, 2, 5, 2, -3, 2, -3, -2], [4, 0, -4, 0, 4, 0, -2, 0, -4, -1, -4, -2, 1, -2, 0, 0, 3, 0], [1, -8, 0, -2, 0, 4, -1, 0, 0, -6, -4, 0, 2, 0, -4, 0, 4, 0], [4, -1, 0, 0, 0, 1, -4, -1, 3, 1, -1, 0, 0, 3, 0, -1, 1, 0], [4, 4, -2, 1, 5, 2, 4, 0, 0, 0, 2, 6, 6, 0, -6, 0, -1, 5], [-4, 0, 0, 0, -4, 0, -8, -4, 4, 0, 2, 5, 2, 5, -7, -1, -2, 1], [-14, 0, 2, -2, -2, 2, -2, 0, -2, 0, 0, 2, -2, -2, 0, 0, 0, 0], [-4, 2, 0, 0, 4, -4, -4, 0, 0, 0, -4, -5, 4, 0, 2, 0, 2, -2], [9, -2, 0, 1, 0, 0, -9, 1, -3, -3, 0, 0, -1, 6, -2, 0, 0, 0], [6, -3, 0, -2, 0, 2, -6, 2, -2, -2, -2, 0, 2, -3, -1, -1, 2, 0], [-15, 4, 0, -4, 0, -1, 15, -11, 7, 1, 1, 0, 4, -4, 3, 3, -1, 0], [-3, 5, 0, 3, -1, 3, -3, 0, 0, 0, 3, 1, 2, 0, -8, 0, -2, 1], [2, 0, 0, 0, 2, 0, -2, 2, -2, 4, 4, -4, -2, -4, 8, 0, 0, 0], [1, 0, -2, 0, 1, 0, 7, -1, -1, -3, -2, -4, -3, -4, 7, 0, -1, 0], [-10, -1, 0, -6, 0, -3, 10, -5, 3, -1, 3, 0, 6, 3, -4, 3, -3, 0], [0, 0, 2, 0, 0, 0, 8, 2, 0, 0, -2, -1, -2, -1, -5, 3, 2, -3], [-12, -3, 2, -4, 4, -1, 4, -6, 4, 0, 0, 4, 4, -4, 0, 2, 0, 2], [5, 1, 2, 0, -5, -2, -5, 3, -5, 1, 0, 1, -5, -1, 0, 1, -1, 1], [-2, 2, 3, -7, 0, -6, 0, -3, 0, -3, 0, 1, 0, -1, 0, 0, 3, 0], [-6, 2, 0, 0, 0, 2, 6, 2, -6, -6, -2, 0, 0, 1, 4, -5, 2, 0], [5, -4, -4, 3, 0, 8, 5, 0, 0, 0, 8, 4, 3, 0, -4, 0, -6, 0], [20, -3, -3, 2, 2, 0, 2, 1, 2, 0, 0, -1, 2, 1, 0, 3, 0, 3], [1, 1, 0, -3, 0, -3, -1, -6, 0, -4, 3, 0, 3, 4, -2, 2, -3, 0], [0, 0, -1, 0, 0, 0, 6, -1, 0, 1, 0, -3, -4, -3, 8, 4, 1, -4], [-3, 0, 3, 0, -3, 0, 1, 0, 3, -1, -6, 0, -4, 0, -4, 3, 5, -3], [-3, -2, 0, 1, 0, 0, 3, -1, -7, -5, 0, 0, -1, 2, -2, -3, 0, 0], [19, -8, -3, 1, 1, 4, 1, 2, 1, -2, 0, -7, 1, 7, 0, -2, 2, -2], [-9, 5, 0, -2, 0, -7, 9, -6, 1, 5, 7, 0, 2, 0, -2, 7, -7, 0], [6, 5, -2, 3, -1, 0, 6, 0, 0, 0, 0, 8, 2, 0, -5, 0, -1, 0], [18, 12, -6, 4, -2, -2, -2, 8, -2, 4, 0, 0, -2, 0, 0, -3, -4, -3], [-5, 6, 5, -3, -1, -10, -1, -4, -1, 4, 0, 2, -1, -2, 0, -1, -4, -1], [-4, -1, -1, 6, -2, 0, -2, 3, -2, 4, 0, -3, -2, 3, 0, 1, -4, 1], [-4, -2, 4, 2, -4, 0, -4, 0, 0, 0, 0, -1, -2, 0, 2, 0, 6, 0], [-1, 0, 1, 0, -1, 0, -7, 0, 1, 1, -4, -1, 0, -1, -4, 4, 5, -4], [0, -1, 0, -4, 0, 0, 0, 0, 2, -4, 0, 0, 4, 9, -1, 1, 0, 0], [4, -3, -6, 0, 2, -1, 4, 0, 0, 0, -1, 4, 2, 0, 4, 0, 2, 2], [3, 5, 0, 6, 0, 1, -3, 6, -1, 11, -1, 0, -6, -8, 6, 1, 1, 0], [0, 0, 2, 0, 0, 0, -2, 2, 0, 4, -2, -3, -9, -3, 8, 1, 6, -1], [-1, 0, 1, 0, -1, 0, 3, 0, 1, 5, 6, 5, -3, 5, -1, 1, -1, -1], [-8, 2, 4, -3, -3, -4, -8, 0, 0, 0, -4, 0, -6, 0, 2, 0, 1, -4], [6, 0, 0, 3, 0, 0, -6, -2, 0, 3, 0, 0, -3, 0, 0, 6, 0, 0], [-14, 2, 0, 0, 0, 2, 14, -1, 7, 5, -2, 0, 0, -1, 4, -1, 2, 0], [13, 4, 3, 4, -3, -4, -3, 0, -3, 0, 0, 5, -3, -5, 0, 0, 0, 0], [12, -8, -4, -2, -2, 2, 12, 0, 0, 0, 2, -3, -4, 0, 6, 0, -2, -2], [2, 0, 1, 0, 2, 0, 6, 3, -2, 2, 5, 3, -2, 3, 0, 0, -3, 0], [-4, 3, 0, 2, 0, -4, 4, 0, 6, 6, 4, 0, -2, 3, -1, 1, -4, 0], [6, 6, 0, 0, 0, -2, -6, -6, -2, 0, 2, 0, 0, 1, 4, 0, -2, 0], [-3, 0, -2, 0, -3, 0, -9, -5, 3, -3, -2, 4, 5, 4, 2, 3, -1, -3], [3, 0, 1, 0, 3, 0, 3, 4, -3, 2, -5, 0, -1, 0, 8, -1, 7, 1], [1, 0, -1, 0, 1, 0, 11, 0, -1, 6, 4, 2, 1, 2, 0, 3, 2, -3], [-2, 0, -3, 0, -2, 0, 8, -5, 2, 4, 0, 3, 4, 3, 0, 2, 4, -2], [-9, 0, 1, 3, -3, 0, -3, 2, -3, -2, 0, 1, -3, -1, 0, 2, 2, 2], [3, 0, -1, 0, 3, 0, -13, 2, -3, 5, 6, 3, 1, 3, 1, 3, -1, -3], [-7, 8, 1, 3, -5, 0, -5, 4, -5, 4, 0, -1, -5, 1, 0, 0, -4, 0], [8, 2, 2, 6, -6, 2, -6, 4, -6, 2, 0, -4, -6, 4, 0, -2, -2, -2], [2, 6, 0, 0, 0, -2, -2, -6, 4, 8, 2, 0, 0, -3, 4, 3, -2, 0], [4, 6, -6, 7, -4, 2, 4, 0, 0, 0, 2, 0, 3, 0, -8, 0, -3, -6], [5, 0, 0, 6, 0, 7, -5, 13, -1, -3, -7, 0, -6, 8, 7, -3, 7, 0], [-11, -3, 3, 4, -3, 4, -3, 0, -3, -1, 0, 2, -3, -2, 0, -2, 1, -2], [-2, 3, 6, 0, 0, -3, -2, 0, 0, 0, -3, -2, 0, 0, 0, 0, 4, -4], [-6, 0, 2, 0, -6, 0, -2, -4, 6, -2, -10, -3, -2, -3, 6, 3, 8, -3], [-6, 6, 0, -1, 4, -6, 4, -4, 4, 5, 0, 3, 4, -3, 0, 7, -5, 7], [-1, 2, 0, -1, 0, -6, 1, -6, 4, 2, 6, 0, 1, -2, -4, 4, -6, 0], [-4, 1, 0, 7, -7, 8, -4, 0, 0, 0, 8, -2, 0, 0, -9, 0, -5, 0], [-10, 8, 0, 5, -9, -2, -10, 0, 0, 0, -2, 0, -4, 0, -6, 0, 3, -3], [-11, 1, 8, -4, -3, -5, -3, -5, -3, -4, 0, 1, -3, -1, 0, 1, 4, 1], [-4, 2, -3, -3, 0, 2, 0, 3, 0, 0, 0, -3, 0, 3, 0, 0, 0, 0], [6, 3, 2, -6, 2, -6, 2, -4, 2, -2, 0, 0, 2, 0, 0, -2, 2, -2], [8, 8, 8, -4, 0, -4, 8, 0, 0, 0, -4, 3, -4, 0, -4, 0, 6, -2], [9, -3, 4, -2, -1, 8, -1, -3, -1, -7, 0, -1, -1, 1, 0, -3, 7, -3], [1, 0, 1, 0, 1, 0, -3, 2, -1, 4, -4, 2, -3, 2, -8, 2, 8, -2], [4, 0, -3, 0, 4, 0, 6, 1, -4, 1, 0, -1, 4, -1, 12, -2, 1, 2], [-6, 0, -4, 0, -6, 0, 8, -10, 6, -1, 8, -6, -1, -6, 0, 4, -9, -4], [-3, 5, 0, -4, 0, -7, 3, -4, 3, 7, 7, 0, 4, -2, -2, -3, -7, 0], [2, -2, 0, 5, 0, 2, -2, 9, -7, -1, -2, 0, -5, -1, 0, 3, 2, 0], [-1, 0, -1, 0, -1, 0, -13, -2, 1, 3, 0, -3, 3, -3, -1, 3, 3, -3], [3, 2, -6, 0, -2, 2, 3, 0, 0, 0, 2, 8, -2, 0, -4, 0, -6, 2], [-16, 4, 0, 4, -11, -3, -16, 0, 0, 0, -3, 2, -7, 0, -1, 0, 2, -1], [23, -4, 0, 3, 0, 4, -23, 11, -7, -3, -4, 0, -3, -4, 0, -2, 4, 0], [-2, 2, 3, 3, -3, 2, -2, 0, 0, 0, 2, 4, 0, 0, -4, 0, 1, 1], [-6, -6, 0, 4, 0, 4, 6, 2, -6, -2, -4, 0, -4, -1, -2, 0, 4, 0], [1, 0, 2, 0, 1, 0, 15, 3, -1, 5, 12, 4, 3, 4, -16, -1, -7, 1], [0, 0, -3, 0, 0, 0, 14, -3, 0, -7, -6, 0, -1, 0, 8, -1, -1, 1], [4, 0, 1, 0, 4, 0, 6, 5, -4, -4, -2, 3, 8, 3, -4, -6, -2, 6], [7, 4, 3, -5, 1, -8, 1, -4, 1, 0, 0, 1, 1, -1, 0, 0, 0, 0], [-2, -1, -2, -2, -2, 4, -2, 0, 0, 0, 4, 5, -4, 0, -3, 0, 4, -1], [2, 6, 0, -3, 0, -2, -2, -1, -3, -3, 2, 0, 3, 5, 4, -5, -2, 0], [-3, 4, -2, 8, -5, 0, -5, 7, -5, 5, 0, -3, -5, 3, 0, -4, -5, -4], [-10, 2, 5, -4, -5, 2, -10, 0, 0, 0, 2, 0, -9, 0, -4, 0, -3, -1], [0, -4, 0, -2, -4, -2, -4, 4, -4, 6, 0, -6, -4, 6, 0, 0, -6, 0], [2, -6, 5, 2, -6, 2, -6, 1, -6, -2, 0, 5, -6, -5, 0, 0, 2, 0], [-8, 4, 0, 4, 0, 0, 8, -8, 4, -2, 0, 0, -4, -11, 4, 9, 0, 0], [1, -4, 4, 1, -5, 4, 1, 0, 0, 0, 4, 5, -4, 0, 0, 0, -5, 1], [7, 2, 0, 2, 0, -3, -7, 11, -1, 11, 3, 0, -2, 0, -1, 3, -3, 0], [6, 0, 2, -6, 6, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, -2], [-14, 0, 0, 1, 0, 3, 14, 0, 2, 6, -3, 0, -1, -7, 3, 6, 3, 0], [14, 4, 2, 1, 5, -4, 14, 0, 0, 0, -4, 4, 6, 0, 0, 0, 7, 2], [-20, -4, 1, 1, -2, 0, -2, 1, -2, 0, 0, -6, -2, 6, 0, -5, 0, -5], [-1, 1, 0, -3, 0, 5, 1, -4, 5, -1, -5, 0, 3, 2, 6, -1, 5, 0], [10, 4, 4, -3, -3, 0, 10, 0, 0, 0, 0, -8, -6, 0, -4, 0, 1, -3], [-16, -4, 0, -6, 0, 0, 16, -13, 17, -3, 0, 0, 6, 3, -4, 5, 0, 0], [-9, -3, -5, -2, 7, -1, 7, -2, 7, -1, 0, -2, 7, 2, 0, 1, 1, 1], [-19, -1, 7, -10, 1, -2, 1, -8, 1, -3, 0, -4, 1, 4, 0, -4, 3, -4], [-4, -6, -5, -3, 6, 10, 6, -1, 6, -1, 0, 5, 6, -5, 0, 4, 1, 4], [-1, 0, 4, 0, -1, 0, 9, 3, 1, 3, -2, 4, -9, 4, 14, 1, 5, -1], [3, -7, 0, -2, 0, 5, -3, 6, -4, -10, -5, 0, 2, -4, -2, -2, 5, 0], [4, 0, 0, 0, 4, 0, 4, 4, -4, 8, 4, -7, 0, -7, 5, 5, 4, -5], [-4, 6, 0, -1, 5, -6, -4, 0, 0, 0, -6, -10, 4, 0, 0, 0, -3, -4], [0, 9, 0, 2, 0, -1, 0, 0, 2, -3, 1, 0, -2, 0, 8, -10, -1, 0], [-3, 0, -5, 0, -3, 0, 33, -8, 3, -1, 6, -7, 3, -7, -5, 5, -7, -5], [12, -9, -7, 2, 3, 3, 12, 0, 0, 0, 3, -2, 5, 0, 6, 0, 2, 1], [8, 0, 3, 11, -8, 8, -8, 5, -8, -2, 0, -1, -8, 1, 0, -4, 2, -4], [1, 0, -7, 0, 1, 0, -5, -6, -1, -3, 8, 1, 8, 1, 0, 2, -11, -2], [7, -11, 2, -3, 8, 1, 7, 0, 0, 0, 1, -8, 5, 0, 10, 0, 1, 6], [17, -2, 0, -2, 0, -3, -17, 5, -5, -7, 3, 0, 2, 4, -5, -5, -3, 0], [-3, 2, -6, 2, 1, -6, -3, 0, 0, 0, -6, 3, 3, 0, 4, 0, -5, 5], [4, 0, -4, 0, 4, 0, -4, 0, -4, -6, -4, -3, 12, -3, -12, -2, -2, 2], [-6, 0, 1, 0, -6, 0, -4, -5, 6, 5, 6, -4, -1, -4, 0, 3, -1, -3], [5, 0, -1, 0, 5, 0, -1, 4, -5, -4, 2, 2, 5, 2, 4, 3, -6, -3], [2, 9, 10, -1, -3, -4, 2, 0, 0, 0, -4, -4, -4, 0, -5, 0, 3, 2], [7, -5, 0, -6, -1, -3, -1, 1, -1, 0, 0, -11, -1, 11, 0, -7, 0, -7], [0, 4, -3, 0, -2, 2, -2, 5, -2, -1, 0, -6, -2, 6, 0, -1, 1, -1], [1, -3, -5, 6, -3, 6, -3, 8, -3, 1, 0, 4, -3, -4, 0, 0, -1, 0], [-16, 8, -1, -8, 4, 0, 4, -3, 4, -2, 0, -5, 4, 5, 0, -4, 2, -4], [15, 8, 0, 9, 0, 2, -15, 11, -11, 3, -2, 0, -9, 6, 10, -10, 2, 0], [6, 10, -3, 2, 5, 2, 6, 0, 0, 0, 2, -2, 7, 0, -12, 0, -9, -3], [-2, 9, 10, 1, -2, -5, -2, 0, 0, 0, -5, 2, -1, 0, -4, 0, 6, 8], [0, -12, 0, 0, 0, 2, 0, -4, 2, -12, -2, 0, 0, 3, -10, -2, 2, 0], [-18, -5, -3, 6, 0, 0, 0, 3, 0, 6, 0, 1, 0, -1, 0, 5, -6, 5], [-1, 0, -5, 0, -1, 0, -13, -6, 1, 0, 4, 2, 5, 2, -12, 5, -4, -5], [8, 0, 1, 0, 8, 0, -20, 9, -8, -7, 0, 9, 5, 9, -8, -6, -7, 6], [20, 2, 0, -3, 0, -9, -20, 2, -4, -4, 9, 0, 3, 15, -7, -10, -9, 0], [-8, -2, 3, -6, 2, -2, 2, -5, 2, -1, 0, -5, 2, 5, 0, -2, 1, -2], [0, 4, 4, 0, 5, -1, 0, 0, 0, 0, -1, 6, 5, 0, -3, 0, -4, 1], [0, 0, -7, 0, 0, 0, 22, -7, 0, 3, 12, -8, 5, -8, -4, 3, -9, -3], [8, -5, -8, -4, 12, -7, 8, 0, 0, 0, -7, 0, 8, 0, 12, 0, 0, 8], [1, 0, -6, 0, 1, 0, -5, -5, -1, 1, 6, 6, -5, 6, -14, 2, -5, -2], [3, 0, 8, 0, 3, 0, -17, 11, -3, 0, -10, -3, -3, -3, 12, -3, 10, 3], [4, 6, -10, 3, 2, 9, 4, 0, 0, 0, 9, 7, 5, 0, -15, 0, -5, -8], [0, 0, 7, 0, 0, 0, -22, 7, 0, 0, -8, -6, -6, -6, 15, 0, 8, 0], [-6, 12, 0, 0, 0, -4, 6, 4, -6, 9, 4, 0, 0, -12, 8, 6, -4, 0], [4, -2, -7, 2, 7, 2, 4, 0, 0, 0, 2, 4, 9, 0, 0, 0, -5, 3], [6, -12, -9, 14, 0, 8, 0, 9, 0, 1, 0, -2, 0, 2, 0, 1, -1, 1], [-8, 0, -8, 0, 5, -1, -8, 0, 0, 0, -1, 0, 5, 0, 1, 0, -2, -1], [-7, -2, 0, -9, 0, 2, 7, -7, 5, 1, -2, 0, 9, 6, 0, 4, 2, 0], [4, 0, 1, 0, 4, 0, 22, 5, -4, 3, 0, 6, -1, 6, -12, -3, 3, 3], [12, 3, 0, 6, 0, 10, -12, 12, -2, 2, -10, 0, -6, -1, 13, -7, 10, 0], [-5, 0, -4, 0, -5, 0, 17, -9, 5, 7, 16, -8, 5, -8, 0, 5, -9, -5], [3, 0, 1, 0, 3, 0, 7, 4, -3, 3, 4, -4, 6, -4, 0, 1, -1, -1], [-5, 0, 3, 0, -5, 0, 27, -2, 5, -3, -6, -1, 1, -1, 5, -1, 3, 1], [6, -2, 0, 5, 0, 7, -6, 8, 0, -2, -7, 0, -5, -9, 5, -2, 7, 0], [0, 0, 4, 0, 0, 0, -2, 4, 0, 9, 6, 0, -1, 0, -12, 2, 3, -2], [-13, 22, -2, 1, 1, -2, 1, 1, 1, 1, 0, 2, 1, -2, 0, -4, -1, -4], [10, 9, -2, -1, 5, -6, 10, 0, 0, 0, -6, -6, 4, 0, -3, 0, 7, -6], [-8, 4, 0, -2, 0, -8, 0, 0, 0, 8, 0, -6, 0, 6, 0, 5, -8, 5], [2, 1, 1, 0, 0, -6, 0, -1, 0, 2, 0, -3, 0, 3, 0, -1, -2, -1], [0, -6, 0, 8, 0, 10, 0, 8, 4, -6, -10, 0, -8, -7, 4, -3, 10, 0], [-12, 2, 0, -8, 0, -4, 12, -12, 8, 8, 4, 0, 8, 5, -2, -4, -4, 0], [-9, -3, -8, -1, 1, 3, -9, 0, 0, 0, 3, -13, 0, 0, 0, 0, 6, -5], [3, 4, 0, 2, 0, -4, -3, 6, -4, 2, 4, 0, -2, 10, 0, 0, -4, 0], [0, 0, 6, 0, 0, 0, -4, 6, 0, 4, 4, 3, -6, 3, 12, -5, 0, 5], [-8, -8, 0, 3, 0, 5, 8, 10, 4, 4, -5, 0, -3, 7, -3, -10, 5, 0], [6, 0, -2, 0, 0, -2, 6, 0, 0, 0, -2, -7, 0, 0, 2, 0, -10, -3], [8, -1, 12, -1, -1, -6, 8, 0, 0, 0, -6, 0, -2, 0, 7, 0, 11, -2], [10, -10, -12, -1, 5, 0, 10, 0, 0, 0, 0, -2, 4, 0, 10, 0, -5, 5], [2, 0, 5, -11, 0, -4, 0, -5, 0, -6, 0, 4, 0, -4, 0, 1, 6, 1], [23, -2, -5, 8, -5, -2, -5, 10, -5, 4, 0, -4, -5, 4, 0, 3, -4, 3], [0, -4, -4, -2, 14, 2, 0, 0, 0, 0, 2, 3, 12, 0, 2, 0, -8, 0], [8, 18, -4, 11, 2, -6, 2, 2, 2, 10, 0, 2, 2, -2, 0, 6, -10, 6], [-5, 0, 0, 0, -5, 0, -13, -5, 5, 3, 13, -3, 1, -3, -12, 3, -10, -3], [-3, 1, 0, 3, 0, 2, 3, -3, -7, -7, -2, 0, -3, -6, 3, -4, 2, 0], [-1, 3, -4, 0, 1, 5, -1, 0, 0, 0, 5, -11, 1, 0, -8, 0, -6, 1], [-14, 21, 3, 4, -4, -2, -4, 1, -4, 2, 0, -1, -4, 1, 0, -7, -2, -7], [0, 0, 2, 0, 0, 0, 20, 2, 0, -3, 7, 8, 8, 8, -20, -2, -10, 2], [-7, -3, 0, 1, 0, 5, 7, 14, -2, 2, -5, 0, -1, 0, 2, -4, 5, 0], [2, -2, -4, 11, -7, 4, 2, 0, 0, 0, 4, 12, 4, 0, -2, 0, -11, -1], [4, 0, -4, 0, 4, 0, 12, 0, -4, 0, 12, 1, 0, 1, -11, 1, -12, -1], [-12, -1, 0, 3, 0, -3, 12, -1, -7, -3, 3, 0, -3, -3, -4, 7, -3, 0], [-8, 0, 2, 0, -8, 0, 24, -6, 8, -1, -11, -6, -4, -6, 12, 4, 10, -4], [-4, -4, 3, 4, -1, -4, -4, 0, 0, 0, -4, -2, 3, 0, 8, 0, -1, -1], [12, -3, 0, 10, 0, 0, -12, 12, -10, -4, 0, 0, -10, -3, -3, 1, 0, 0], [11, -3, 0, -1, -1, 3, 11, 0, 0, 0, 3, -3, -2, 0, 0, 0, 0, 5], [1, 0, -4, 0, 1, 0, -9, -3, -1, -1, 4, 1, 3, 1, 0, -5, -5, 5], [-5, 0, 0, 0, -5, 0, -3, -5, 5, 3, -4, -12, -7, -12, 15, 6, 7, -6], [-33, -7, 2, -2, 7, -1, 7, -9, 7, -2, 0, 5, 7, -5, 0, 3, 2, 3], [-10, -6, 0, -7, 0, 6, 10, -13, 1, -3, -6, 0, 7, -7, 0, 3, 6, 0], [-6, 0, 4, 0, -6, 0, 2, -2, 6, 0, 2, -3, -4, -3, -7, -5, -2, 5], [0, 1, 3, -8, 11, 1, 0, 0, 0, 0, 1, 0, 3, 0, -2, 0, 6, -3], [3, -8, -5, -4, 7, -8, 7, -2, 7, 6, 0, -5, 7, 5, 0, 2, -6, 2], [3, 9, -4, 2, 6, 5, 3, 0, 0, 0, 5, 12, 8, 0, -14, 0, -3, 4], [8, 4, 0, -2, 0, -4, -8, -4, -2, -6, 4, 0, 2, -7, 0, 4, -4, 0], [-11, -5, 4, -4, -1, -2, -1, -3, -1, -7, 0, -5, -1, 5, 0, 1, 7, 1], [-13, -10, 8, -10, 3, -2, -13, 0, 0, 0, -2, 3, -7, 0, 12, 0, 13, 3], [-1, 0, 5, 0, -1, 0, 7, 4, 1, 7, -4, 10, -4, 10, 0, -1, 11, 1], [-10, 6, 2, 4, -6, 4, -10, 0, 0, 0, 4, 7, -2, 0, -10, 0, 2, -5], [-16, 2, -2, 5, -1, 6, -16, 0, 0, 0, 6, 8, 4, 0, -8, 0, -11, 9], [8, -8, -3, 4, 2, 4, 2, 1, 2, -7, 0, 2, 2, -2, 0, -4, 7, -4], [-2, 6, -10, -4, 7, -1, -2, 0, 0, 0, -1, -4, 3, 0, -5, 0, -4, 1], [-15, -6, 6, -3, -5, -2, -15, 0, 0, 0, -2, -9, -8, 0, 8, 0, 7, -7], [8, -9, 5, -4, -6, 6, -6, 1, -6, -4, 0, 3, -6, -3, 0, 5, 4, 5], [3, 0, -4, 0, 3, 0, 1, -1, -3, -1, 8, -8, 1, -8, -16, 1, -9, -1], [-1, -9, 0, 3, 0, 11, 1, 2, 1, -3, -11, 0, -3, -8, 2, -1, 11, 0], [1, 0, -5, 0, 1, 0, 15, -4, -1, 3, -6, -1, 4, -1, 16, -2, 9, 2], [-8, 0, -1, 0, -8, 0, 2, -9, 8, -1, -2, 3, 6, 3, 2, -2, 1, 2], [-6, 0, 7, 0, -6, 0, -4, 1, 6, 2, 0, -1, -3, -1, 8, -4, 2, 4], [-12, -15, 0, -1, 0, -1, 12, -8, 6, -1, 1, 0, 1, 14, -16, 0, -1, 0], [6, 0, -5, 0, 6, 0, -12, 1, -6, -6, -8, 0, 4, 0, 5, -2, 2, 2], [0, 1, 1, 3, -3, 1, 0, 0, 0, 0, 1, -12, 0, 0, -2, 0, 2, -9], [7, -2, 0, -1, 0, -2, -7, 3, 7, -1, 2, 0, 1, 0, -4, -6, -2, 0], [0, 0, -3, 0, 0, 0, -28, -3, 0, -8, -11, -1, 6, -1, 0, -4, 3, 4], [12, -14, -2, -1, -4, 6, 12, 0, 0, 0, 6, 0, -5, 0, 8, 0, 9, -2], [2, 0, -8, 0, 2, 0, 14, -6, -2, 2, 8, 9, 2, 9, -8, -4, -6, 4], [12, -13, -1, -2, 4, 1, 4, -3, 4, 3, 0, -11, 4, 11, 0, 4, -3, 4], [-4, -1, 0, -5, 7, -2, -4, 0, 0, 0, -2, -2, 2, 0, 3, 0, -3, 2], [6, 0, -4, 0, 6, 0, -2, 2, -6, -6, -6, 3, 8, 3, 7, -7, 0, 7], [15, -7, -2, 10, -8, 9, 15, 0, 0, 0, 9, 8, 2, 0, -2, 0, -3, 2], [21, -11, 4, -6, -3, -1, -3, -1, -3, -8, 0, -3, -3, 3, 0, 1, 8, 1], [10, -12, 2, -6, -2, 6, -2, 0, -2, -6, 0, 0, -2, 0, 0, -6, 6, -6]]
